@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: Packager.pm 249 2008-05-05 20:35:05Z kutterma $
+# $Id: Packager.pm 339 2009-09-29 21:16:47Z kutterma $
 #
 # ======================================================================
 
@@ -14,7 +14,7 @@ use strict;
 use vars;
 
 use vars qw($VERSION $SUPPORTED_TYPES);
-use version; $VERSION = qv('0.710.05');
+use version; $VERSION = qv('0.710.09');
 $SUPPORTED_TYPES = { };
 
 sub BEGIN {
@@ -213,7 +213,14 @@ sub process_related {
   # As it turns out, the Content-ID and start parameters are optional
   # according to the MIME and SOAP specs. In the event that the head cannot
   # be found, the head/root entity is used as a starting point.
-  my $start = get_multipart_id($entity->head->mime_attr('content-type.start'));
+    # [19 Mar 2008] Modified by Feng Li <feng.li@sybase.com>
+    # Check optional start parameter, then optional Content-ID, then create/add
+    # Content-ID (the same approach as in SOAP::Lite 0.66)
+
+    #my $start = get_multipart_id($entity->head->mime_attr('content-type.start'));
+    my $start = get_multipart_id($entity->head->mime_attr('content-type.start'))
+        || get_multipart_id($entity->parts(0)->head->mime_attr('content-id'));
+
   if (!defined($start) || $start eq "") {
       $start = $self->generate_random_string(10);
       $entity->parts(0)->head->add('content-id',$start);
@@ -242,7 +249,7 @@ sub process_related {
     if ($start && $pid eq $start) {
       $env = $part->bodyhandle->as_string;
     } else {
-      $self->push_part($part) if (defined($part->bodyhandle));
+      $self->push_part($part);
     }
   }
 #  die "Can't find 'start' parameter in multipart MIME message\n"
